package info.aspirecn.cloud.yysj.service.impl;

import info.aspirecn.cloud.yysj.dao.es.YysjGatewayFirstIndex;
import info.aspirecn.cloud.yysj.dao.es.YysjGatewaySecondIndex;
import info.aspirecn.cloud.yysj.model.entity.*;
import info.aspirecn.cloud.yysj.model.response.ChildOrderInfo;
import info.aspirecn.cloud.yysj.model.response.OrderInfo;
import info.aspirecn.cloud.yysj.model.response.OrderInfoList;
import info.aspirecn.cloud.yysj.service.DbService;
import info.aspirecn.cloud.yysj.service.OrderService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.*;

/**
 * @author dingliqiang
 */
@Slf4j
@Service
public class OrderServiceImpl implements OrderService {

    @Autowired
    private YysjGatewayFirstIndex yysjGatewayFirstIndex;

    @Autowired
    private YysjGatewaySecondIndex yysjGatewaySecondIndex;

    @Autowired
    private DbService dbService;

    @Override
    public OrderInfoList getOrderList(String userId, String orderId, String startTime, String endTime,
                                      int pageNum, int pageSize) {
        List<OrderInfo> orderInfos = new ArrayList<>();
        // 计算分页
        int form = (pageNum - 1) * pageSize;
        // 获取主订单列表
        GatewayFirstLogList gatewayFirstLogList = yysjGatewayFirstIndex.getFirstLogList(userId, orderId,
                startTime, endTime, form, pageSize);
        // 查询主订单下面的子订单列表
        for (GatewayFirstLog gatewayFirstLog : gatewayFirstLogList.getGatewayFirstLogs()) {
            // 获取子订单信息
            List<ChildOrderInfo> childOrderInfoList = getOrderDetail(gatewayFirstLog.getOrderId());
            // 统计子订单价格
            long price = 0L;
            for (ChildOrderInfo childOrderInfo : childOrderInfoList) {
                // 查询各个产品价格
                price += Long.parseLong(childOrderInfo.getPrice());
            }
            // 设置信息
            orderInfos.add(new OrderInfo()
                    .setOrderId(gatewayFirstLog.getOrderId())
                    .setRequestTime(gatewayFirstLog.getDateTime())
                    .setOrderType(gatewayFirstLog.getType())
                    .setOrderAmount(String.valueOf(price))
            );
        }
        OrderInfoList orderInfoList =  new OrderInfoList();
        // 设置订单信息
        orderInfoList.setOrderInfos(orderInfos);
        // 设置分页
        orderInfoList.setTotal(gatewayFirstLogList.getTotal());
        orderInfoList.setPageSize((long)pageSize);
        orderInfoList.setPageNum((long)pageNum);
        orderInfoList.setPageTotal((gatewayFirstLogList.getTotal()-1)/pageSize + 1);
        return orderInfoList;
    }

    @Override
    public List<ChildOrderInfo> getOrderDetail(String orderId) {
        List<ChildOrderInfo> childOrderInfoList = new ArrayList<>();
        // 获取该主订单的子订单列表
        GatewaySecondLogList gatewaySecondLogList = yysjGatewaySecondIndex.getSecondLogList(orderId);
        for (GatewaySecondLog gatewaySecondLog : gatewaySecondLogList.getGatewaySecondLogs()) {
            childOrderInfoList.add(new ChildOrderInfo()
                    .setOrderId(gatewaySecondLog.getOrderId())
                    .setProduceId(gatewaySecondLog.getProductId())
                    .setPrice(gatewaySecondLog.getMoney()));
        }
        // 根据产品ID查询产品名称
        for (ChildOrderInfo childOrderInfo : childOrderInfoList) {
            Produce produce = dbService.getProduceInfo(Long.valueOf(childOrderInfo.getProduceId()));
            childOrderInfo.setProduceName(produce.getProduceName());
        }
        return childOrderInfoList;
    }

}
